@@ -1,10 +1,31 @@
-;;; tex-jp.el - Support for Japanese TeX.
-;;
+;;; tex-jp.el --- Support for Japanese TeX.
 
-;; Maintainer: Hidenobu Nabetani <nabe@debian.or.jp>
-;; Version: 11.06
+;; Copyright (C) 1999, 2001 Hidenobu Nabetani <nabe@debian.or.jp>
+;; Copyright (C) 2002, 2003, 2004 Free Software Foundation
+
+;; Author:     KOBAYASHI Shinji <koba@flab.fujitsu.co.jp>
+;; Maintainer: Masayuki Ataka <ataka@milk.freemail.ne.jp>
+;; Keywords: tex
+
+;; This file is part of AUCTeX.
+
+;; AUCTeX is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+
+;; AUCTeX is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with AUCTeX; see the file COPYING.  If not, write to the Free
+;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+;; 02111-1307, USA.
+
+;;; Commentary:
 
-;;; Commentary: 
 ;; This file was written by KOBAYASHI Shinji <koba@flab.fujitsu.co.jp>
 ;; based on many patches developed by Japanese NetNews community.
 ;; Japanese message translation by MATUI Takao <mat@nuis.ac.jp>.
@@ -15,59 +36,56 @@
 
 ;;; Customization
 
+(defgroup AUCTeX-jp nil
+  "Japanese support in AUCTeX."
+  :group 'AUCTeX)
+
 ;; TeX-format-list need to be set in tex.el, not tex-jp.el.
 ;(setq TeX-format-list
 ;      (append '(("JLATEX" japanese-latex-mode
-;		 "\\\\\\(documentstyle[^%\n]*{j\\|documentclass[^%\n]*{j\\)")
+;                 "\\\\\\(documentstyle\\|documentclass\\)[^%\n]*{\\(j[s-]?\\|t\\)\\(article\\|report\\|book\\|slides\\)")
 ;		("JTEX" japanese-plain-tex-mode
 ;		 "-- string likely in Japanese TeX --"))
 ;	      TeX-format-list))
 
 (defvar japanese-TeX-command-list
-  (list (list "jTeX" "jtex '\\nonstopmode\\input %t'"
-	      'TeX-run-TeX nil t)
-	(list "jLaTeX" "jlatex '\\nonstopmode\\input{%t}'"
-	      'TeX-run-LaTeX nil t)
-	(list "pTeX" "ptex '\\nonstopmode\\input %t'"
-	      'TeX-run-TeX nil t)
-	(list "pLaTeX" "platex '\\nonstopmode\\input{%t}'"
-	      'TeX-run-LaTeX nil t)
-	(list "Mendex" "memdex %s" 'TeX-run-command nil t)		    
-	(list "jBibTeX" "jbibtex %s" 'TeX-run-BibTeX nil nil))
+  ;; Changed to double quotes for Windows afflicted people.  I don't
+  ;; use the %(latex) and %(tex) shorthands here because I have not
+  ;; clue whether Omega-related versions exist.  --dak
+  '(("jTeX" "%(PDF)jtex %S%(PDFout) \"%(mode)\\input %t\""
+     TeX-run-TeX nil (plain-tex-mode))
+    ("jLaTeX" "%(PDF)jlatex %S%(PDFout) \"%(mode)\\input{%t}\""
+     TeX-run-LaTeX nil (latex-mode))
+    ("pTeX" "%(PDF)ptex %S%(PDFout) \"%(mode)\\input %t\""
+     TeX-run-TeX nil (plain-tex-mode))
+    ("pLaTeX" "%(PDF)platex %S%(PDFout) \"%(mode)\\input{%t}\""
+     TeX-run-LaTeX nil (latex-mode))
+    ("Mendex" "mendex %s" TeX-run-command nil t)
+    ("jBibTeX" "jbibtex %s" TeX-run-BibTeX nil t))
   "Additional list of commands to execute in japanese-LaTeX-mode")
 
 (setq TeX-command-list
-      (append japanese-TeX-command-list TeX-command-list))
-       
-;; the following code is needed to change mode-menu in japanese-LaTeX-mode.
-(easy-menu-define TeX-mode-menu
-    TeX-mode-map
-    "Menu used in TeX mode."
-  (append '("Command")
-	  '(("Command on"
-	     [ "Master File" TeX-command-select-master
-	       :keys "C-c C-c" :style radio
-	       :selected (eq TeX-command-current 'TeX-command-master) ]
-	     [ "Buffer" TeX-command-select-buffer
-	       :keys "C-c C-b" :style radio
-	       :selected (eq TeX-command-current 'TeX-command-buffer) ]
-	     [ "Region" TeX-command-select-region
-	       :keys "C-c C-r" :style radio
-	       :selected (eq TeX-command-current 'TeX-command-region) ]))
-	  (let ((file 'TeX-command-on-current))
-	    (mapcar 'TeX-command-menu-entry TeX-command-list))))
+      (append japanese-TeX-command-list
+	      '(("-" "" nil nil t)) ;; separator for command menu
+	      TeX-command-list))
 
-(define-key LaTeX-mode-map [menu-bar Command] (cons "Command" TeX-mode-menu))
-;; up to here to change mode-menu in japanese-LaTeX-mode.
+;; Menus
+
+(easy-menu-define plain-TeX-mode-command-menu
+  plain-TeX-mode-map
+  "Command menu used in TeX mode."
+  (TeX-mode-specific-command-menu 'plain-tex-mode))
+
+(easy-menu-define LaTeX-mode-command-menu
+  LaTeX-mode-map
+  "Command menu used in LaTeX mode."
+  (TeX-mode-specific-command-menu 'latex-mode))
 
 (setq LaTeX-command-style
-      (append (if (string-equal LaTeX-version "2")
-		  '(("^ams" "amsjlatex")
-		    ("^jslides$" "jslitex")
-		    ("^j-?\\(article\\|report\\|book\\)$" "jlatex"))
-                '(("^j-\\(article\\|report\\|book\\)$" "jlatex")
-                  ("^j\\(article\\|report\\|book\\)$" "platex")
-                  ("." "jlatex")))
+      (append '(("^j-\\(article\\|report\\|book\\)$"
+		 "%(PDF)jlatex %S%(PDFout)")
+		("^[jt]s?\\(article\\|report\\|book\\)$"
+		 "%(PDF)platex %S%(PDFout)"))
 	      LaTeX-command-style))
 
 (setcdr (assoc "%l" TeX-expand-list)
@@ -79,71 +97,71 @@
 (if (featurep 'mule)
     (if (featurep 'xemacs)
 	(progn
-	  (defvar TeX-japanese-process-input-coding-system 
+	  (defvar TeX-japanese-process-input-coding-system
 	    (find-coding-system 'euc-japan)
 	    "TeX-process' coding system with standard input.")
-	  (defvar TeX-japanese-process-output-coding-system 
+	  (defvar TeX-japanese-process-output-coding-system
 	    (find-coding-system 'junet)
 	    "TeX-process' coding system with standard output."))
-      (if (>= emacs-major-version 20)
-	  (progn
-	    (defvar TeX-japanese-process-input-coding-system 'euc-japan
-	      "TeX-process' coding system with standard input.")
-	    (defvar TeX-japanese-process-output-coding-system 'junet
-	      "TeX-process' coding system with standard output."))
-	(progn
-	  (defvar TeX-japanese-process-input-coding-system *euc-japan*
-	    "TeX-process' coding system with standard input.")
-	  (defvar TeX-japanese-process-output-coding-system *junet*
-	    "TeX-process' coding system with standard output.")))))
+      ;; FSF Emacs 20 or later.
+      (defvar TeX-japanese-process-input-coding-system 'euc-japan
+	"TeX-process' coding system with standard input.")
+      (defvar TeX-japanese-process-output-coding-system 'junet
+	"TeX-process' coding system with standard output.")))
 
-(defvar japanese-TeX-command-default "jTeX"
-  "The default command for TeX-command in the japanese-TeX mode.")
-(make-variable-buffer-local 'japanese-TeX-command-default)
+(defcustom japanese-TeX-command-default "pTeX"
+  "*The default command for TeX-command in the japanese-TeX mode."
+  :group 'AUCTeX-jp
+  :type 'string)
+  (make-variable-buffer-local 'japanese-TeX-command-default)
 
-(defvar japanese-LaTeX-command-default "jLaTeX"
-  "The default command for TeX-command in the japanese-LaTeX mode.")
-(make-variable-buffer-local 'japanese-LaTeX-command-default)
+(defcustom japanese-LaTeX-command-default "LaTeX"
+  "*The default command for TeX-command in the japanese-LaTeX mode."
+  :group 'AUCTeX-jp
+  :type 'string)
+  (make-variable-buffer-local 'japanese-LaTeX-command-default)
 
-(defvar japanese-LaTeX-default-style "jarticle"
-  "*Default when creating new Japanese documents.")
-(make-variable-buffer-local 'japanese-LaTeX-default-style)
+(defcustom japanese-LaTeX-default-style "jarticle"
+  "*Default when creating new Japanese documents."
+  :group 'AUCTeX-jp
+  :type 'string)
 
-(defvar japanese-LaTeX-style-list
-  '(("book")
-    ("article")
-    ("letter")
-    ("slides")
-    ("report")
-    ("jbook")
+(defcustom japanese-LaTeX-style-list
+  '(("j-article")
+    ("j-report")
     ("j-book")
     ("jarticle")
-    ("j-article")
-    ("jslides")
+    ("jbook")
     ("jreport")
-    ("j-report"))
-  "*List of Japanese document styles.")
-(make-variable-buffer-local 'japanese-LaTeX-style-list)
+    ("jslides")
+    ("tarticle")
+    ("treport")
+    ("tbook"))
+  "*List of Japanese document styles."
+  :group 'AUCTeX-jp
+  :type '(repeat (group (string :format "%v"))))
+
+(setq LaTeX-style-list
+      (append japanese-LaTeX-style-list LaTeX-style-list))
 
 ;;; Coding system
 
 (if (and (featurep 'xemacs)
 	 (featurep 'mule))
     (setq TeX-after-start-process-function
-	  (function (lambda (process)
-		      (set-process-input-coding-system
-		       process
-		       TeX-japanese-process-input-coding-system)
-		      (set-process-output-coding-system
-		       process
-		       TeX-japanese-process-output-coding-system)))))
+	  (lambda (process)
+	    (set-process-input-coding-system
+	     process
+	     TeX-japanese-process-input-coding-system)
+	    (set-process-output-coding-system
+	     process
+	     TeX-japanese-process-output-coding-system))))
 
 ;;; Japanese Parsing
 
-(if (featurep 'mule)
-(progn
+(when (featurep 'mule)
 
-(defconst LaTeX-auto-regexp-list 
+(defconst LaTeX-auto-regexp-list
   (append
    '(("\\\\\\(new\\|provide\\)command\\*?{?\\\\\\(\\([a-zA-Z]\\|\\cj\\)+\\)}?\\[\\([0-9]+\\)\\]\\[\\([^\n\r]*\\)\\]"
       (2 4 5) LaTeX-auto-optional)
@@ -194,9 +212,9 @@
      1 LaTeX-auto-bibitem))
   "List of regexp-list expressions matching BibTeX items.")
 
-))
+)
 
-(defconst TeX-auto-full-regexp-list 
+(defconst TeX-auto-full-regexp-list
   (append LaTeX-auto-regexp-list plain-TeX-auto-regexp-list)
   "Full list of regular expression matching TeX macro definitions.")
 
@@ -208,8 +226,8 @@
 (add-hook 'plain-TeX-mode-hook 'japanese-plain-tex-mode-initialization)
 
 ;;;###autoload
-(defun japanese-plain-tex-mode ()
-  "Major mode for editing files of input for Japanese plain TeX.
+(TeX-defun japanese-plain-tex-mode ()
+  "Major mode in %s for editing Japanese plain TeX files.
 Set japanese-TeX-mode to t, and enters plain-tex-mode."
   (interactive)
   (setq japanese-TeX-mode t)
@@ -223,8 +241,8 @@ Set japanese-TeX-mode to t, and enters plain-tex-mode."
 (add-hook 'LaTeX-mode-hook 'japanese-latex-mode-initialization)
 
 ;;;###autoload
-(defun japanese-latex-mode ()
-  "Major mode for editing files of input for Japanese plain TeX.
+(TeX-defun japanese-latex-mode ()
+  "Major mode in %s for editing Japanese LaTeX files.
 Set japanese-TeX-mode to t, and enters latex-mode."
   (interactive)
   (setq japanese-TeX-mode t)
@@ -236,15 +254,13 @@ Set japanese-TeX-mode to t, and enters latex-mode."
       (progn
 	(setq TeX-command-default japanese-LaTeX-command-default)
 	(setq LaTeX-default-style japanese-LaTeX-default-style)
-	(setq LaTeX-style-list japanese-LaTeX-style-list)
 	(setq TeX-command-BibTeX "jBibTeX")
 	(setq japanese-TeX-mode nil))))
 
 
 ;;; MULE paragraph filling.
 
-(if (string-lessp "20" emacs-version)
-;; This function is copied from 
+;; This function is copied from
 ;; fill-region-as-paragraph in fill.el --- fill commands for Emacs
 ;; Copyright (C) 1985, 86, 92, 94, 95, 96, 1997 Free Software Foundation, Inc.
 (defun LaTeX-fill-region-as-para-do (from to justify)
@@ -268,7 +284,7 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 
     (beginning-of-line)
     (setq from (point))
-  
+
     ;; Delete all but one soft newline at end of region.
     ;; And leave TO before that one.
     (goto-char to)
@@ -283,7 +299,7 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 ;;;     ;; If there was no newline, and there is text in the paragraph, then
 ;;;     ;; create a newline.
 ;;;     (if (and (not oneleft) (> to from-plus-indent))
-;;; 	(newline))
+;;;	(newline))
     (goto-char from-plus-indent))
 
   (if (not (> to (point)))
@@ -519,20 +535,20 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 		  (LaTeX-indent-line)
 		  ;; Set prefixcol so whitespace in the prefix won't get lost.
 		  (and fill-prefix (not (equal fill-prefix ""))
-                       (setq prefixcol (current-column)))))
+		       (setq prefixcol (current-column)))))
 	      ;; Justify the line just ended, if desired.
 	      (if justify
-                (if (save-excursion (skip-chars-forward " \t") (eobp))
-                    (progn
-                      (delete-horizontal-space)
-                      (justify-current-line justify t t))
+		(if (save-excursion (skip-chars-forward " \t") (eobp))
+		    (progn
+		      (delete-horizontal-space)
+		      (justify-current-line justify t t))
 		    (forward-line -1)
 		    (justify-current-line justify nil t)
 		    (forward-line 1))))))
 	;; Leave point after final newline.
 	(goto-char (point-max)))
       (unless (eobp)
-	(forward-char 1))))))
+	(forward-char 1)))))
 
 ;;; Support for various self-insert-command
 
@@ -555,7 +571,7 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 ;;; Error Messages
 
 (if japanese-TeX-error-messages
-    (setq TeX-error-description-list
+(setq TeX-error-description-list
   '(("Bad \\\\line or \\\\vector argument.*" .
 "$B@~$N79$-$r;XDj$9$k!$(B\\line$B$^$?$O(B\\vector$B$N:G=i$N0z?t$,IT@5$G$9!%(B")
 
@@ -774,7 +790,7 @@ thebibliography$B4D6-$G0z?t$rK:$l$?>l9g$K$b@8$8$^$9!%(B")
 small caps$B%U%)%s%H$,8F$S$@$5$l$k$3$H$K$J$j$^$9!%$3$NLdBj$O(B\\load$BL?Na$r(B
 $B;H$($P2r7h$G$-$^$9!%(B")
 
-    ("Font .* not found." .                                    
+    ("Font .* not found." .
 "$BL$CN$N(Bfamily/series/shape/size$B$NAH$_9g$o$;$N%U%)%s%H$,;XDj$5$l$^$7$?!%(B
 $B$3$N%(%i!<$,5/$-$k%1!<%9$O(B2$B$D9M$($i$l$^$9!%(B
    1) \\size$B%^%/%m$G;H$($J$$%5%$%:$rA*Br$7$h$&$H$7$?!%(B
@@ -813,22 +829,22 @@ TeX$B$,;}$C$F$$$kNN0h0J>e$K%O%$%U%M!<%7%g%s>pJs$rM?$($h$&$H$7$F$$$^$9!%(B
 $B$"$^$j;H$o$J$$C18l$N(B\\hyphenation$BL?Na$r<h$j=|$$$F!$Be$o$j$K(B\\-$BL?Na$r;H$C(B
 $B$F$/$@$5$$!%(B
 
-hash size 
+hash size
 =========
 $BL?NaL>$NDj5A$^$?$OAj8_;2>H%i%Y%k$NDj5A$,B?$9$.$^$9!%(B
 
-input stack size 
+input stack size
 ================
 $B$3$N%(%i!<$O$*$=$i$/L?NaDj5ACf$N8m$j$K$h$k$b$N$G$9!%Nc$($P!$<!$NL?Na$O(B
 $B:F5"E*Dj5A$H$J$C$F$*$j!$<+J,<+?H$r;H$C$F(B\\gnu$B$rDj5A$7$F$$$^$9!%(B
 
-          \\newcommand{\\gnu}{a \\gnu} % $B$3$l$O$@$a(B
+	  \\newcommand{\\gnu}{a \\gnu} % $B$3$l$O$@$a(B
 
 $B$3$N(B\\gnu$BL?Na$r8+$D$1$k$H(BTeX$B$O(B\\gnu$B$,2?$r$&$_$@$9$N$+$r7hDj$7$h$&$H$7(B
 $B$F$=$NKvHx$r$$$D$^$G$bDI$$$D$E$1!$$d$,$F(B``input stack''$B$r;H$$$-$C$F$7(B
 $B$^$$$^$9!%(B
 
-main memory size 
+main memory size
 ================
 $B$3$l$O!$(BTeX$B$,C;$$%U%!%$%k$r=hM}$7$F$$$k;~$K;H$$$-$k2DG=@-$N$"$k%a%b%j(B
 $B$N$R$H$D$G$9!%(Bmain memory$B$r;H$$$-$k$N$O<!$N(B3$B$D$N>l9g$N$$$:$l$+$G$9!%(B
@@ -853,7 +869,7 @@ TeX$B$N%a%b%j$,$$$C$Q$$$K$J$C$F$$$k$N$+$b$7$l$^$;$s!%K\Ev$K(BTeX$B$NMFNL$rD6
 $B=*HG$r:n$k;~$^$G$3$NLdBj$OC*>e$2$7$F$*$-$^$7$g$&!%F~NO%U%!%$%k$,JQ$o$k(B
 $B$HLdBj$,2r>C$5$l$k>l9g$b$"$k$N$G$9!%(B
 
-pool size 
+pool size
 =========
 $BAj8_;2>H$N(B\\label$B$,B?$9$.$k$+!$L?Na$NDj5A$,B?$9$.$k$+$N$I$A$i$+$G$9!%(B
 $B@53N$K$$$($P!$Dj5A$7$?%i%Y%kL>$*$h$SL?NaL>$K;H$C$?J8;z?t$,B?$9$.$k$H$$(B
@@ -861,7 +877,7 @@ pool size
 $B$7!$$3$N%(%i!<$O!$(B\\setcounter$B$J$I$N%+%&%s%?L?Na$d(B\\newenvironment$B!&(B
 \\newtheorem$BL?Na$N0z?t$N=*$o$j$r<($91&3g8L$rK:$l$?>l9g$K$b@8$8$^$9!%(B
 
-save size 
+save size
 =========
 $B$3$N%(%i!<$O!$@k8@$NM-8zHO0O$dL?Na!&4D6-$,$"$^$j$K$b?<$/F~$l;R$K$J$C$F(B
 $B$$$k>l9g$K@8$8$^$9!%$?$H$($P!$(B\\multiput$BL?Na$N0z?t$K(Bpicture$B4D6-$,$"$j!$(B
@@ -874,7 +890,7 @@ save size
 $B%(%G%#%?$K$h$j$^$9!%F~NO%U%!%$%k$rD4$Y$F$_$F!$;XE&$5$l$?J8;z$,8+$D$+$i(B
 $B$J$$>l9g$K$O%m!<%+%k%,%$%I$r8+$F$/$@$5$$!%(B")
 
-    ("Undefined control sequence."   .  
+    ("Undefined control sequence."   .
 "TeX$B$,L$Dj5A$NL?NaL>$rH/8+$7$^$7$?!%$*$=$i$/F~NO$N8m$j$G$7$g$&!%$b$7$3(B
 $B$N%(%i!<$,(BLaTeX$BL?Na$N=hM}Cf$K@8$8$?>l9g$O!$$=$NL?Na$O4V0c$C$?0LCV$KCV$+(B
 $B$l$F$$$^$9!%Nc$($P!$%j%9%H4D6-$NCf$G$J$$$N$K(B\\item$BL?Na$,;H$o$l$?>l9g$J$I(B
@@ -908,10 +924,10 @@ save size
 "$B%Z!<%8$rJ,3d$9$k$?$a$NE,@Z$J>l=j$,8+$D$1$i$l$:!$==J,$J%F%-%9%H$N$J$$(B
 $B%Z!<%8$,$G$-$F$7$^$$$^$7$?!%(B")
 
-;; New list items should be placed here 
-;; 
-;; ("err-regexp" . "context") 
-;; 
+;; New list items should be placed here
+;;
+;; ("err-regexp" . "context")
+;;
 ;; the err-regexp item should match anything
 
     (".*" . "$B$4$a$s$J$5$$!%3:Ev$9$k%X%k%W%a%C%;!<%8$,$"$j$^$;$s!%(B"))))
